==> estateplat-common-1.2.3-20180502.071924-72-sources.jar: cn/gtmap/estateplat/model/server/core/BdcTszt.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/11/22
 * @description 不动产登记推送状态
 */
@Table(name = "bdc_tszt")
public class BdcTszt {
    @Id
    private String tsid; //推送id
    private String proid; //项目id
    private String qlid; //权利id
    private String tsdx; //权利ID
    private String tsxs; //推送形式
    private Integer tscs; //推送次数
    private String tszt; //推送状态
    private Date tssj;  //推送时间
    private String tsr; //推送人
    private String tsqk; //推送情况
    private String bz; //备注
    private String xmly;//项目来源
    private String qllx;//权利类型
    private Integer qszt;//权属状态

    public String getTsid() {
        return tsid;
    }

    public void setTsid(String tsid) {
        this.tsid = tsid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getTsdx() {
        return tsdx;
    }

    public void setTsdx(String tsdx) {
        this.tsdx = tsdx;
    }

    public String getTsxs() {
        return tsxs;
    }

    public void setTsxs(String tsxs) {
        this.tsxs = tsxs;
    }

    public Integer getTscs() {
        return tscs;
    }

    public void setTscs(Integer tscs) {
        this.tscs = tscs;
    }

    public String getTszt() {
        return tszt;
    }

    public void setTszt(String tszt) {
        this.tszt = tszt;
    }

    public Date getTssj() {
        return tssj;
    }

    public void setTssj(Date tssj) {
        this.tssj = tssj;
    }

    public String getTsr() {
        return tsr;
    }

    public void setTsr(String tsr) {
        this.tsr = tsr;
    }

    public String getTsqk() {
        return tsqk;
    }

    public void setTsqk(String tsqk) {
        this.tsqk = tsqk;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getXmly() {
        return xmly;
    }

    public void setXmly(String xmly) {
        this.xmly = xmly;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }
}

==> estateplat-common-1.2.3-20190121.014905-219-sources.jar: cn/gtmap/estateplat/model/server/core/BdcTszt.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/11/22
 * @description 不动产登记推送状态
 */
@Table(name = "bdc_tszt")
public class BdcTszt {
    @Id
    private String tsid; //推送id
    private String proid; //项目id
    private String qlid; //权利id
    private String tsdx; //权利ID
    private String tsxs; //推送形式
    private Integer tscs; //推送次数
    private String tszt; //推送状态
    private Date tssj;  //推送时间
    private String tsr; //推送人
    private String tsqk; //推送情况
    private String bz; //备注
    private String xmly;//项目来源
    private String qllx;//权利类型
    private Integer qszt;//权属状态
    private String tsjdmc;//推送节点名称

    public String getTsid() {
        return tsid;
    }

    public void setTsid(String tsid) {
        this.tsid = tsid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getTsdx() {
        return tsdx;
    }

    public void setTsdx(String tsdx) {
        this.tsdx = tsdx;
    }

    public String getTsxs() {
        return tsxs;
    }

    public void setTsxs(String tsxs) {
        this.tsxs = tsxs;
    }

    public Integer getTscs() {
        return tscs;
    }

    public void setTscs(Integer tscs) {
        this.tscs = tscs;
    }

    public String getTszt() {
        return tszt;
    }

    public void setTszt(String tszt) {
        this.tszt = tszt;
    }

    public Date getTssj() {
        return tssj;
    }

    public void setTssj(Date tssj) {
        this.tssj = tssj;
    }

    public String getTsr() {
        return tsr;
    }

    public void setTsr(String tsr) {
        this.tsr = tsr;
    }

    public String getTsqk() {
        return tsqk;
    }

    public void setTsqk(String tsqk) {
        this.tsqk = tsqk;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getXmly() {
        return xmly;
    }

    public void setXmly(String xmly) {
        this.xmly = xmly;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public String getTsjdmc() {
        return tsjdmc;
    }

    public void setTsjdmc(String tsjdmc) {
        this.tsjdmc = tsjdmc;
    }
}
